@@ -36,7 +36,7 @@ class Task():
         self._internal_connection, self._external_connection = connections
         self.gatherer: Gatherer = None
         if (use_gatherer):
-            self.gatherer = Gatherer(self._external_connection)
+            self.gatherer = Gatherer(self._external_connection, self)
         self._target = target
         ctx = mp.get_context(method=start_method)
         self.process: Process = ctx.Process(target=Task._call_function, args=(self._internal_connection, self._target), daemon=daemon)
@@ -122,6 +122,7 @@ class Task():
         if self.gatherer:
             self.gatherer.record_invocation()
         self._invocations += 1
+
         if not args and not kwargs:
             self._external_connection.send(None)
         else:
@@ -175,8 +176,9 @@ class Task():
             return self.gatherer.get_all_results()
 
         result_list = []
-        while self._invocations < self._gathered:
+        while self._invocations > self._gathered:
             result = self._external_connection.recv()
+            self._gathered += 1
             result_list.append(result)
         return result_list
 
@@ -194,4 +196,10 @@ class Task():
                     out = function(*args, **kwargs)
             else:
                 out = function()
+            
+            start_time = time.time()
             conn.send(out)
+            if config.verbose:
+                print(f'EZ-TASK result {mp.current_process()} time to write {time.time() - start_time}')
+
+
